/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.application;

import java.util.List;

import org.tinygroup.appconfig.AppConfig;
import org.tinygroup.appconfig.AppConfigManager;
import org.tinygroup.context.Context;

/**
 * 
 * 功能说明: 应用程序的接口抽象，主要完成管理应用程序配置、注册应用处理器以及开启与关闭应用程序功能。
 * <p>
 * 系统版本: v1.0<br>
 * 开发人员: renhui <br>
 * 开发时间: 2013-2-22 <br>
 * 功能描述: 写明作用，调用方式，使用场景，以及特殊情况<br>
 */
public interface Application extends AppConfig{

	/**
	 * 设置应用处理器列表
	 * 
	 * @param applicationProcessors
	 */
	void setApplicationProcessors(
			List<ApplicationProcessor> applicationProcessors);

	/**
	 * 
	 * 设置应用程序的配置管理对象
	 * @param appConfigManager
	 */
	void setAppConfigManager(AppConfigManager appConfigManager);

	/**
	 * 返回应用环境
	 * 
	 * @return
	 */
	Context getContext();

	/**
	 * 启动
	 */
	void start();

	/**
	 * 停止
	 */
	void stop();
}
